@@ -1,4 +1,4 @@
-// Copyright 2022-2023 The NATS Authors
+// Copyright 2022-2025 The NATS Authors
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
 // You may obtain a copy of the License at
@@ -581,6 +581,132 @@ func TestPublishMsg(t *testing.T) {
 	}
 }
 
+func TestPublishWithTTL(t *testing.T) {
+	srv := RunBasicJetStreamServer()
+	defer shutdownJSServerAndRemoveStorage(t, srv)
+	nc, err := nats.Connect(srv.ClientURL())
+	if err != nil {
+		t.Fatalf("Unexpected error: %v", err)
+	}
+
+	js, err := jetstream.New(nc)
+	if err != nil {
+		t.Fatalf("Unexpected error: %v", err)
+	}
+	defer nc.Close()
+
+	ctx, cancel := context.WithTimeout(context.Background(), 5*time.Second)
+	defer cancel()
+	stream, err := js.CreateStream(ctx, jetstream.StreamConfig{
+		Name: "foo", Subjects: []string{"FOO.*"}, MaxMsgSize: 64, AllowMsgTTL: true})
+	if err != nil {
+		t.Fatalf("Unexpected error: %v", err)
+	}
+
+	ack, err := js.Publish(ctx, "FOO.1", []byte("msg"), jetstream.WithMsgTTL(1*time.Second))
+	if err != nil {
+		t.Fatalf("Unexpected error: %v", err)
+	}
+	gotMsg, err := stream.GetMsg(ctx, ack.Sequence)
+	if err != nil {
+		t.Fatalf("Unexpected error: %v", err)
+	}
+	if ttl := gotMsg.Header.Get("Nats-TTL"); ttl != "1s" {
+		t.Fatalf("Expected message to have TTL header set to 1s; got: %s", ttl)
+	}
+	time.Sleep(1500 * time.Millisecond)
+	_, err = stream.GetMsg(ctx, ack.Sequence)
+	if !errors.Is(err, jetstream.ErrMsgNotFound) {
+		t.Fatalf("Expected not found error; got: %v", err)
+	}
+}
+
+func TestMsgDeleteMarkerMaxAge(t *testing.T) {
+	srv := RunBasicJetStreamServer()
+	defer shutdownJSServerAndRemoveStorage(t, srv)
+	nc, err := nats.Connect(srv.ClientURL())
+	if err != nil {
+		t.Fatalf("Unexpected error: %v", err)
+	}
+
+	js, err := jetstream.New(nc)
+	if err != nil {
+		t.Fatalf("Unexpected error: %v", err)
+	}
+	defer nc.Close()
+
+	ctx, cancel := context.WithTimeout(context.Background(), 5*time.Second)
+	defer cancel()
+	stream, err := js.CreateStream(ctx, jetstream.StreamConfig{
+		Name: "foo", Subjects: []string{"FOO.*"}, AllowMsgTTL: true, SubjectDeleteMarkerTTL: 50 * time.Second, MaxAge: 1 * time.Second})
+	if err != nil {
+		t.Fatalf("Unexpected error: %v", err)
+	}
+
+	_, err = js.Publish(ctx, "FOO.1", []byte("msg1"))
+	if err != nil {
+		t.Fatalf("Unexpected error: %v", err)
+	}
+	time.Sleep(1500 * time.Millisecond)
+	gotMsg, err := stream.GetLastMsgForSubject(ctx, "FOO.1")
+	if err != nil {
+		t.Fatalf("Unexpected error: %v", err)
+	}
+	if ttlMarker := gotMsg.Header.Get("Nats-Marker-Reason"); ttlMarker != "MaxAge" {
+		t.Fatalf("Expected message to have Marker-Reason header set to MaxAge; got: %s", ttlMarker)
+	}
+	if ttl := gotMsg.Header.Get("Nats-TTL"); ttl != "50s" {
+		t.Fatalf("Expected message to have Nats-TTL header set to 50s; got: %s", ttl)
+	}
+}
+
+func TestPublishAsyncWithTTL(t *testing.T) {
+	srv := RunBasicJetStreamServer()
+	defer shutdownJSServerAndRemoveStorage(t, srv)
+	nc, err := nats.Connect(srv.ClientURL())
+	if err != nil {
+		t.Fatalf("Unexpected error: %v", err)
+	}
+
+	js, err := jetstream.New(nc)
+	if err != nil {
+		t.Fatalf("Unexpected error: %v", err)
+	}
+	defer nc.Close()
+
+	ctx, cancel := context.WithTimeout(context.Background(), 5*time.Second)
+	defer cancel()
+	stream, err := js.CreateStream(ctx, jetstream.StreamConfig{
+		Name: "foo", Subjects: []string{"FOO.*"}, MaxMsgSize: 64, AllowMsgTTL: true})
+	if err != nil {
+		t.Fatalf("Unexpected error: %v", err)
+	}
+
+	paf, err := js.PublishAsync("FOO.1", []byte("msg"), jetstream.WithMsgTTL(1*time.Second))
+	if err != nil {
+		t.Fatalf("Unexpected error: %v", err)
+	}
+	var ack *jetstream.PubAck
+	select {
+	case ack = <-paf.Ok():
+	case <-time.After(5 * time.Second):
+		t.Fatalf("Did not receive ack")
+	}
+
+	gotMsg, err := stream.GetMsg(ctx, ack.Sequence)
+	if err != nil {
+		t.Fatalf("Unexpected error: %v", err)
+	}
+	if ttl := gotMsg.Header.Get("Nats-TTL"); ttl != "1s" {
+		t.Fatalf("Expected message to have TTL header set to 1s; got: %s", ttl)
+	}
+	time.Sleep(1500 * time.Millisecond)
+	_, err = stream.GetMsg(ctx, ack.Sequence)
+	if !errors.Is(err, jetstream.ErrMsgNotFound) {
+		t.Fatalf("Expected not found error; got: %v", err)
+	}
+}
+
 func TestPublish(t *testing.T) {
 	// Only very basic test cases, as most use cases are tested in TestPublishMsg
 	tests := []struct {
@@ -648,6 +774,41 @@ func TestPublish(t *testing.T) {
 	}
 }
 
+func TestPublishTimeout(t *testing.T) {
+	srv := RunBasicJetStreamServer()
+	defer shutdownJSServerAndRemoveStorage(t, srv)
+	nc, err := nats.Connect(srv.ClientURL())
+	if err != nil {
+		t.Fatalf("Unexpected error: %v", err)
+	}
+
+	js, err := jetstream.New(nc, jetstream.WithDefaultTimeout(200*time.Millisecond))
+	if err != nil {
+		t.Fatalf("Unexpected error: %v", err)
+	}
+	defer nc.Close()
+
+	// create stream with no ack to force timeout
+	_, err = js.CreateStream(context.Background(), jetstream.StreamConfig{
+		Name:     "foo",
+		Subjects: []string{"FOO.*"},
+		NoAck:    true,
+	})
+	if err != nil {
+		t.Fatalf("Unexpected error: %v", err)
+	}
+
+	now := time.Now()
+	_, err = js.Publish(context.Background(), "FOO.1", []byte("msg"))
+	if !errors.Is(err, context.DeadlineExceeded) {
+		t.Fatalf("Expected deadline exceeded error; got: %v", err)
+	}
+	since := time.Since(now)
+	if since < 200*time.Millisecond || since > 500*time.Millisecond {
+		t.Fatalf("Expected timeout to be around 200ms; got: %v", since)
+	}
+}
+
 func TestPublishMsgAsync(t *testing.T) {
 	type publishConfig struct {
 		msg              *nats.Msg
@@ -701,6 +862,45 @@ func TestPublishMsgAsync(t *testing.T) {
 				},
 			},
 		},
+		{
+			name: "publish with ack timeout set",
+			msgs: []publishConfig{
+				{
+					msg: &nats.Msg{
+						Data:    []byte("msg 1"),
+						Subject: "FOO.1",
+					},
+					expectedAck: jetstream.PubAck{
+						Stream:   "foo",
+						Sequence: 1,
+						Domain:   "",
+					},
+				},
+				{
+					msg: &nats.Msg{
+						Data:    []byte("msg 2"),
+						Subject: "FOO.1",
+					},
+					expectedAck: jetstream.PubAck{
+						Stream:   "foo",
+						Sequence: 2,
+						Domain:   "",
+					},
+				},
+				{
+					msg: &nats.Msg{
+						Data:    []byte("msg 3"),
+						Subject: "FOO.2",
+					},
+					expectedAck: jetstream.PubAck{
+						Stream:   "foo",
+						Sequence: 3,
+						Domain:   "",
+					},
+				},
+			},
+			timeout: time.Second,
+		},
 		{
 			name: "publish 3 messages with message ID, with duplicate",
 			msgs: []publishConfig{
@@ -1170,7 +1370,11 @@ func TestPublishMsgAsync(t *testing.T) {
 				t.Fatalf("Unexpected error: %v", err)
 			}
 
-			js, err := jetstream.New(nc)
+			opts := []jetstream.JetStreamOpt{}
+			if test.timeout != 0 {
+				opts = append(opts, jetstream.WithPublishAsyncTimeout(test.timeout))
+			}
+			js, err := jetstream.New(nc, opts...)
 			if err != nil {
 				t.Fatalf("Unexpected error: %v", err)
 			}
@@ -1552,3 +1756,117 @@ func TestPublishAsyncRetryInErrHandler(t *testing.T) {
 		t.Fatalf("Expected 10 messages in the stream; got: %d", info.State.Msgs)
 	}
 }
+
+func TestPublishAsyncAckTimeout(t *testing.T) {
+	s := RunBasicJetStreamServer()
+	defer shutdownJSServerAndRemoveStorage(t, s)
+
+	nc, err := nats.Connect(s.ClientURL())
+	if err != nil {
+		t.Fatalf("Unexpected error: %v", err)
+	}
+
+	errs := make(chan error, 1)
+	js, err := jetstream.New(nc,
+		jetstream.WithPublishAsyncTimeout(50*time.Millisecond),
+		jetstream.WithPublishAsyncErrHandler(func(js jetstream.JetStream, m *nats.Msg, e error) {
+			errs <- e
+		}),
+	)
+	if err != nil {
+		t.Fatalf("Unexpected error: %v", err)
+	}
+	defer nc.Close()
+
+	_, err = js.CreateStream(context.Background(), jetstream.StreamConfig{Name: "foo", Subjects: []string{"FOO.*"}, NoAck: true})
+	if err != nil {
+		t.Fatalf("Unexpected error: %v", err)
+	}
+
+	ack, err := js.PublishAsync("FOO.A", []byte("hello"))
+	if err != nil {
+		t.Fatalf("Unexpected error: %v", err)
+	}
+
+	select {
+	case <-ack.Ok():
+		t.Fatalf("Expected timeout")
+	case err := <-ack.Err():
+		if !errors.Is(err, jetstream.ErrAsyncPublishTimeout) {
+			t.Fatalf("Expected error: %v; got: %v", jetstream.ErrAsyncPublishTimeout, err)
+		}
+	case <-time.After(time.Second):
+		t.Fatalf("Did not receive ack timeout")
+	}
+
+	// check if error callback is called
+	select {
+	case err := <-errs:
+		if !errors.Is(err, jetstream.ErrAsyncPublishTimeout) {
+			t.Fatalf("Expected error: %v; got: %v", jetstream.ErrAsyncPublishTimeout, err)
+		}
+	case <-time.After(time.Second):
+		t.Fatalf("Did not receive error from error handler")
+	}
+
+	if js.PublishAsyncPending() != 0 {
+		t.Fatalf("Expected no pending messages")
+	}
+
+	select {
+	case <-js.PublishAsyncComplete():
+	case <-time.After(100 * time.Millisecond):
+		t.Fatalf("Did not receive completion signal")
+	}
+}
+
+func TestPublishAsyncClearStall(t *testing.T) {
+	s := RunBasicJetStreamServer()
+	defer shutdownJSServerAndRemoveStorage(t, s)
+
+	nc, err := nats.Connect(s.ClientURL())
+	if err != nil {
+		t.Fatalf("Unexpected error: %v", err)
+	}
+
+	js, err := jetstream.New(nc,
+		jetstream.WithPublishAsyncTimeout(500*time.Millisecond),
+		jetstream.WithPublishAsyncMaxPending(100))
+	if err != nil {
+		t.Fatalf("Unexpected error: %v", err)
+	}
+	defer nc.Close()
+
+	// use stream with no acks to test stalling
+	_, err = js.CreateStream(context.Background(), jetstream.StreamConfig{Name: "foo", Subjects: []string{"FOO.*"}, NoAck: true})
+	if err != nil {
+		t.Fatalf("Unexpected error: %v", err)
+	}
+
+	for range 100 {
+		_, err := js.PublishAsync("FOO.A", []byte("hello"), jetstream.WithStallWait(1*time.Nanosecond))
+		if err != nil {
+			t.Fatalf("Unexpected error: %v", err)
+		}
+	}
+	// after publishing 100 messages, next one should fail with ErrTooManyStalledMsgs
+	_, err = js.PublishAsync("FOO.A", []byte("hello"), jetstream.WithStallWait(50*time.Millisecond))
+	if !errors.Is(err, jetstream.ErrTooManyStalledMsgs) {
+		t.Fatalf("Expected error: %v; got: %v", jetstream.ErrTooManyStalledMsgs, err)
+	}
+
+	// after publish timeout all pending messages should be cleared
+	// and we should be able to publish again
+	select {
+	case <-js.PublishAsyncComplete():
+	case <-time.After(2 * time.Second):
+		t.Fatalf("Did not receive completion signal")
+	}
+
+	if _, err = js.PublishAsync("FOO.A", []byte("hello")); err != nil {
+		t.Fatalf("Unexpected error: %v", err)
+	}
+	if js.PublishAsyncPending() != 1 {
+		t.Fatalf("Expected 1 pending message; got: %d", js.PublishAsyncPending())
+	}
+}
