@@ -1,4 +1,4 @@
-// Copyright 2012-2022 The NATS Authors
+// Copyright 2012-2023 The NATS Authors
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
 // You may obtain a copy of the License at
@@ -177,10 +177,10 @@ func TestAuthServers(t *testing.T) {
 	opts.Password = "foo"
 
 	opts.Port = 1222
-	as1 := RunServerWithOptions(opts)
+	as1 := RunServerWithOptions(&opts)
 	defer as1.Shutdown()
 	opts.Port = 1224
-	as2 := RunServerWithOptions(opts)
+	as2 := RunServerWithOptions(&opts)
 	defer as2.Shutdown()
 
 	pservers := strings.Join(plainServers, ",")
@@ -682,7 +682,7 @@ func (d *checkPoolUpdatedDialer) Dial(network, address string) (net.Conn, error)
 		doReal = true
 	} else if d.final {
 		d.ra++
-		return nil, fmt.Errorf("On purpose")
+		return nil, errors.New("On purpose")
 	} else {
 		d.ra++
 		if d.ra == 15 {
@@ -698,12 +698,12 @@ func (d *checkPoolUpdatedDialer) Dial(network, address string) (net.Conn, error)
 		d.conn = c
 		return c, nil
 	}
-	return nil, fmt.Errorf("On purpose")
+	return nil, errors.New("On purpose")
 }
 
 func TestServerPoolUpdatedWhenRouteGoesAway(t *testing.T) {
 	if err := serverVersionAtLeast(1, 0, 7); err != nil {
-		t.Skipf(err.Error())
+		t.Skip(err.Error())
 	}
 	s1Opts := test.DefaultTestOptions
 	s1Opts.Host = "127.0.0.1"
